"use client";

import { fetchCsvData } from "@/app/utils/csv";
import React, { useEffect, useState } from "react";

export default function Page() {
  const [loading, setLoading] = useState(true);
  const [links, setLinks] = useState<Record<string, string[]>>({});

  useEffect(() => {
    fetchData();
    async function fetchData() {
      try {
        setLoading(true);
        const links: Record<string, string[]> = {};

        const cadastreAreaCodes = await fetchCsvData<{ KU_KOD: number }>(
          "https://services.cuzk.cz/sestavy/cis/SC_SEZNAMKUKRA_DOTAZ.zip",
        ).then((areas) => areas.map(({ KU_KOD }) => KU_KOD.toString()));

        const yearsBack = 5;
        const currentYear = new Date().getFullYear();
        const [fromYear, toYear] = [currentYear - yearsBack, currentYear];

        for (let code of cadastreAreaCodes) {
          links[code] = [];
          for (let year = fromYear; year <= toYear; year++) {
            const url = `https://nahlizenidokn.cuzk.cz/nas_proxy/NASProxy.ashx?cenoveudaje&${code}&RCU_${code}_${year}.ZIP`;
            links[code].push(url.toString());
          }
        }
        setLinks(links);
      } catch (error) {
        console.error(error);
      } finally {
        setLoading(false);
      }
    }
  }, []);

  if (loading) {
    return (
      <main className="w-screen h-screen font-mono flex flex-col items-center justify-center space-y-4">
        <svg className="animate-spin h-5 w-5 mr-3" viewBox="0 0 24 24">
          <circle
            className="opacity-25"
            cx="12"
            cy="12"
            r="10"
            stroke="currentColor"
            strokeWidth="4"
          ></circle>
          <path
            className="opacity-75"
            fill="currentColor"
            d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"
          ></path>
        </svg>
        <span className="text-gray-700 dark:text-gray-300 text-lg">
          Loading...
        </span>
      </main>
    );
  }

  return (
    <main className="w-screen h-screen font-mono">
      {Object.entries(links).map(([code, urls]) => (
        <React.Fragment key={code}>
          <span key={code}>
            <span>{code}: </span>
            {urls.map((url) => (
              <React.Fragment key={url}>
                <a
                  key={url}
                  href={url}
                  className="text-blue-600 dark:text-blue-500 hover:underline"
                >
                  {url
                    .split("&")
                    ?.pop()
                    ?.split("_")
                    ?.pop()
                    ?.split(".")
                    .shift() ?? "ERROR"}
                </a>{" "}
              </React.Fragment>
            ))}
          </span>
          <br />
        </React.Fragment>
      ))}
    </main>
  );
}
