"use client";

import MapLibre, { Layer, Source } from "react-map-gl/maplibre";
import "maplibre-gl/dist/maplibre-gl.css";

export const Map = () => {
  const baseUrl =
    typeof window !== "undefined" ? `${window.location.origin}` : "";
  return (
    <MapLibre
      initialViewState={{
        longitude: 14.4378,
        latitude: 50.0755,
        zoom: 16,
      }}
      style={{ width: "100%", height: "100vh" }}
      mapStyle="https://basemaps.cartocdn.com/gl/dark-matter-gl-style/style.json"
    >
      <Source
        type="vector"
        tiles={[`${baseUrl}/api/cgs/tiles/radon50/1/{z}/{x}/{y}`]}
        minzoom={16}
      >
        <Layer
          type="fill"
          source-layer="geojsonLayer"
          beforeId="building"
          paint={{
            "fill-color": [
              "match",
              ["get", "radon_popis"],
              "vysoký",
              "rgba(255, 105, 180, 1)", // Hot Pink for high radiation
              "střední",
              "rgba(255, 182, 193, 1)", // Light Pink for medium radiation
              "nízký",
              "rgba(255, 240, 245, 1)", // Lavender Blush for low radiation
              "kvartér, hlubší podloží vysoký",
              "rgba(255, 140, 190, 1)", // Slightly lighter Hot Pink for high radiation in deeper subsoil
              "kvartér, hlubší podloží střední",
              "rgba(255, 200, 210, 1)", // Slightly lighter Light Pink for medium radiation in deeper subsoil
              "kvartér, hlubší podloží nízký",
              "rgba(255, 245, 250, 1)", // Slightly lighter Lavender Blush for low radiation in deeper subsoil
              "nestanoven",
              "rgba(255, 255, 255, 1)", // White for undefined
              "rgba(0, 0, 0, 0)", // default color if no match
            ],
            "fill-outline-color": "rgba(156, 156, 156, 1)",
            "fill-opacity": 0.5,
          }}
        />
      </Source>

      <Source
        type="vector"
        tiles={[`${baseUrl}/api/cuzk/tiles/5/{z}/{x}/{y}`]}
        minzoom={14}
      >
        <Layer
          type="line"
          source-layer="geojsonLayer"
          paint={{ "line-color": "#6D8C00" }}
        />
      </Source>

      <Source
        type="vector"
        tiles={[`${baseUrl}/api/cuzk/tiles/3/{z}/{x}/{y}`]}
        minzoom={14}
      >
        <Layer
          type="line"
          source-layer="geojsonLayer"
          paint={{ "line-color": "#BCAF4D" }}
        />
      </Source>
    </MapLibre>
  );
};
