import { fetchCsvData } from "@/app/utils/csv";

async function generatePriceMapLinks(yearsBack: number = 10) {
  const links: Record<string, string[]> = {};

  const cadastreAreaCodes = await fetchCsvData<{ KU_KOD: number }>(
    "https://services.cuzk.cz/sestavy/cis/SC_SEZNAMKUKRA_DOTAZ.zip",
  ).then(areas => areas.map(({ KU_KOD }) => KU_KOD.toString()));

  const currentYear = new Date().getFullYear();
  const [fromYear, toYear] = [currentYear - yearsBack, currentYear];

  for (let code of cadastreAreaCodes) {
    links[code] = [];
    for (let year = fromYear; year <= toYear; year++) {
      // 
      const url = `https://nahlizenidokn.cuzk.cz/nas_proxy/NASProxy.ashx?cenoveudaje&${code}&RCU_${code}_${year}.ZIP`;
      links[code].push(url.toString());
    }
  }
  return links;
}

async function main() {
  const links = await generatePriceMapLinks();
  console.log(links);
}

main();
