#!/usr/bin/env nix-shell
#! nix-shell -i bash
#! nix-shell -p bash gnused curl aria2 ripgrep parallel unzip gdal tippecanoe jq

cadastre_offices=$(curl -s 'https://datamonikon.vercel.app/api/cuzk/enums/administration/cadastre-office' | jq -c '.[] | select(.TYP_PRAC == 2)')

cadastre_areas=$(curl -s "https://datamonikon.vercel.app/api/cuzk/enums/administration/cadastre-area")

echo "$cadastre_offices" | while read -r office; do
  kod=$(echo "$office" | jq -r '.KOD')
  nazev=$(echo "$office" | jq -r '.NAZEV_ZKRACENY')
  echo "Processing \"$nazev\" ($kod)"

  files=$(echo "$cadastre_areas" | jq -r --arg kod "$kod" '.[] | select(.PRARES_KOD == ($kod | tonumber)) | "https://services.cuzk.cz/gml/inspire/cp/epsg-4258/\(.KU_KOD).zip"')

  mkdir -p "data/$kod"

  wait=$(aria2c -i <(echo "$files") -d "./data/$kod" --continue --quiet)

  find "./data/${kod}" -name '*.zip' | parallel -j+0 "unzip -o -d './data/${kod}' '{}' && rm '{}'"
  find "./data/${kod}" -name '*.xml' | parallel -j+0 "ogr2ogr -sql 'SELECT * FROM CadastralParcel' -f FlatGeobuf './data/${kod}/{/.}.fgb' '{}' && rm -f '{}' && rm -f './data/${kod}/{/.}.gfs'"

  # Merge all .fgb files into one using ogrmerge.py with the -single option
  merged_fgb="./data/${kod}/merged.fgb"
  ogrmerge.py -single -f FlatGeobuf -o "$merged_fgb" $(find "./data/${kod}" -name '*.fgb')

  # Remove individual .fgb files after merging
  find "./data/${kod}" -name '*.fgb' ! -name 'merged.fgb' -exec rm -f {} +

  tippecanoe --extra-detail=16 --no-tiny-polygon-reduction --no-simplification-of-shared-nodes --simplify-only-low-zooms --coalesce-densest-as-needed --layer "${kod}" -n "${nazev}" -o "./data/${kod}/${kod}.mbtiles" --force "$merged_fgb" 
done


mkdir -p "all_mbtiles"
mv "./data/*/*.mbtiles" "all_mbtiles/"
tile-join --no-tile-size-limit -o "cz.mbtiles" "all_mbtiles"
